summaryrefslogtreecommitdiff
path: root/src/menu.c
diff options
context:
space:
mode:
authorPaul Eggert <eggert@cs.ucla.edu>2011-04-29 10:56:27 -0700
committerPaul Eggert <eggert@cs.ucla.edu>2011-04-29 10:56:27 -0700
commitd01a78266d12561b46777a2156914d12d8099c4f (patch)
tree3fa5ec64d44faeca79a6fe89b88362cda723fdff /src/menu.c
parent7fd47d5ce2020a22f8db9776e8d1f47891b966dc (diff)
downloademacs-d01a78266d12561b46777a2156914d12d8099c4f.tar.gz
* lisp.h (EMACS_INTPTR): Remove. All uses changed to intptr_t.
(EMACS_UINTPTR): Likewise, with uintptr_t.
Diffstat (limited to 'src/menu.c')
-rw-r--r--src/menu.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/menu.c b/src/menu.c
index 5162ee083bf..7a3edcb6f4f 100644
--- a/src/menu.c
+++ b/src/menu.c
@@ -800,9 +800,9 @@ digest_single_submenu (int start, int end, int top_level_items)
if (!NILP (descrip))
wv->lkey = descrip;
wv->value = 0;
/* The EMACS_INTPTR cast avoids a warning. There's no problem
as long as pointers have enough bits to hold small integers. */
- wv->call_data = (!NILP (def) ? (void *) (EMACS_INTPTR) i : 0);
+ wv->call_data = (!NILP (def) ? (void *) (intptr_t) i : 0);
wv->enabled = !NILP (enable);
if (NILP (type))
@@ -913,7 +913,7 @@ find_and_call_menu_selection (FRAME_PTR f, int menu_bar_items_used, Lisp_Object
entry = XVECTOR (vector)->contents[i + MENU_ITEMS_ITEM_VALUE];
/* Treat the pointer as an integer. There's no problem
as long as pointers have enough bits to hold small integers. */
- if ((EMACS_INTPTR) client_data == i)
+ if ((intptr_t) client_data == i)
{
int j;
struct input_event buf;
@@ -800,9 +800,9 @@ digest_single_submenu (int start, int end, int top_level_items)
wv->lkey = descrip;
wv->value = 0;
- /* The EMACS_INTPTR cast avoids a warning. There's no problem
+ /* The intptr_t cast avoids a warning. There's no problem
as long as pointers have enough bits to hold small integers. */